@@ -1,6 +1,7 @@
 from pspring import ConfigurationProvider, Configuration
 from .secretsmngr import SecretsManager
 import logging,json
+from datetime import datetime
 
 logger = logging.getLogger(__name__)
 config = Configuration.getConfig(__name__)
@@ -12,13 +13,22 @@ class SecretsMgrConfigProvider(ConfigurationProvider):
         self.subscriptions = []
         self.mgr = SecretsManager(secretId=secretId,region=region)
         self.refresh()
+        self.lastUpdated = int(datetime.now().timestamp())
+        self.timeout = kargs.get("timeout") or config.getProperty("PSPRING_AWS_SM_CONFIG_TIMEOUT") or config.getProperty("PSPRING_CONFIG_TIMEOUT")
 
     def getProperty(self,propertyName):
+        self.checkForRefresh()
         return self.secretValue.get(propertyName)
 
+    def checkForRefresh(self):
+        lastUpdatedSeconds = int(datetime.now().timestamp()) - self.lastUpdated
+        if(self.timeout != None and lastUpdatedSeconds > int(self.timeout)):
+            self.lastUpdated = int(datetime.now().timestamp())
+            self.refresh()
+
     def refresh(self):
         self.secretValue = self.mgr.getSecretValue()
-        #self.publish()
+        self.publish()
 
     def subscribe(self,callback):
         self.subscriptions.append(callback)
